# truehost-workplace-api-client
API for managing email and workplace service subscriptions.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 1.0.10
- Generator version: 7.13.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import workplace_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import workplace_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import workplace_client
from workplace_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://https://workplace-console.truehost.cloud/api
# See configuration.py for a list of all supported configuration parameters.
configuration = workplace_client.Configuration(
    host = "http://https://workplace-console.truehost.cloud/api"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: BearerAuth
configuration.api_key['BearerAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['BearerAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with workplace_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = workplace_client.AvailablePackagesApi(api_client)

    try:
        # Get available subscriptions.
        api_response = api_instance.available_packages_list()
        print("The response of AvailablePackagesApi->available_packages_list:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AvailablePackagesApi->available_packages_list: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://https://workplace-console.truehost.cloud/api*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AvailablePackagesApi* | [**available_packages_list**](docs/AvailablePackagesApi.md#available_packages_list) | **GET** /available-packages/ | Get available subscriptions.
*ChangeQuotaApi* | [**change_quota_create**](docs/ChangeQuotaApi.md#change_quota_create) | **POST** /change-quota/ | Change email quota.
*CreateAliasApi* | [**create_alias_create**](docs/CreateAliasApi.md#create_alias_create) | **POST** /create-alias/ | Create email alias.
*DeleteAliasApi* | [**delete_alias_create**](docs/DeleteAliasApi.md#delete_alias_create) | **POST** /delete-alias/ | Delete alias.
*DeleteEmailApi* | [**delete_email_create**](docs/DeleteEmailApi.md#delete_email_create) | **POST** /delete-email/ | Delete email.
*DnsInfoApi* | [**dns_info_create**](docs/DnsInfoApi.md#dns_info_create) | **POST** /dns-info/ | 
*DomainApi* | [**domain_create**](docs/DomainApi.md#domain_create) | **POST** /domain/ | Update domain subscription status, delete, suspend, unsuspend, etc...
*DomainAliasApi* | [**domain_alias_create**](docs/DomainAliasApi.md#domain_alias_create) | **POST** /domain-alias/ | Get domain alias list.
*DomainInfoApi* | [**domain_info_create**](docs/DomainInfoApi.md#domain_info_create) | **POST** /domain-info/ | Get domain subscription details.
*GetTokenApi* | [**get_token_create**](docs/GetTokenApi.md#get_token_create) | **POST** /get-token/ | 
*ImportApi* | [**import_create**](docs/ImportApi.md#import_create) | **POST** /import/ | Bulk create emails.
*RefreshTokenApi* | [**refresh_token_create**](docs/RefreshTokenApi.md#refresh_token_create) | **POST** /refresh-token/ | 
*ResetPasswordApi* | [**reset_password_create**](docs/ResetPasswordApi.md#reset_password_create) | **POST** /reset-password/ | Reset subscription email password.
*SubscriptionInfoApi* | [**subscription_info_create**](docs/SubscriptionInfoApi.md#subscription_info_create) | **POST** /subscription-info/ | Get subscription usage info.
*SubscriptionsApi* | [**subscriptions_create**](docs/SubscriptionsApi.md#subscriptions_create) | **POST** /subscriptions/ | Create a new email subscription, it will create a new subscription for the domain if emails list is not empty
*SubscriptionsApi* | [**subscriptions_list**](docs/SubscriptionsApi.md#subscriptions_list) | **GET** /subscriptions/ | 
*SubscriptionsApi* | [**subscriptions_read**](docs/SubscriptionsApi.md#subscriptions_read) | **GET** /subscriptions/{context_id}/ | Get subscription details
*SubscriptionsApi* | [**update_subscription_status**](docs/SubscriptionsApi.md#update_subscription_status) | **POST** /subscriptions/{context_id}/ | Update subscription status, delete, suspend, unsuspend, etc...
*UpgradeApi* | [**upgrade_create**](docs/UpgradeApi.md#upgrade_create) | **POST** /upgrade/ | Upgrade subscription.


## Documentation For Models

 - [AliasDisplay](docs/AliasDisplay.md)
 - [ChangeEmailQuota](docs/ChangeEmailQuota.md)
 - [ChangeQuotaCreate200Response](docs/ChangeQuotaCreate200Response.md)
 - [DeleteAlias](docs/DeleteAlias.md)
 - [DeleteEmail](docs/DeleteEmail.md)
 - [DnsInfoCreate200Response](docs/DnsInfoCreate200Response.md)
 - [DnsInfoCreateRequest](docs/DnsInfoCreateRequest.md)
 - [Domain](docs/Domain.md)
 - [DomainAction](docs/DomainAction.md)
 - [EmailAlias](docs/EmailAlias.md)
 - [EmailDisplay](docs/EmailDisplay.md)
 - [ImportCreateRequest](docs/ImportCreateRequest.md)
 - [OpenExchangeCreateAccount](docs/OpenExchangeCreateAccount.md)
 - [OrderDisplay](docs/OrderDisplay.md)
 - [PasswordReset](docs/PasswordReset.md)
 - [ServiceAction](docs/ServiceAction.md)
 - [SubScriptionInfo](docs/SubScriptionInfo.md)
 - [SubscriptionDetails](docs/SubscriptionDetails.md)
 - [SubscriptionInfoCreate200Response](docs/SubscriptionInfoCreate200Response.md)
 - [SubscriptionInfoResponse](docs/SubscriptionInfoResponse.md)
 - [SubscriptionsRead200Response](docs/SubscriptionsRead200Response.md)
 - [TokenObtainPair](docs/TokenObtainPair.md)
 - [TokenRefresh](docs/TokenRefresh.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="BearerAuth"></a>
### BearerAuth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

support@truehost.cloud


